# gami

[![Main-PyTest](https://github.com/WesRoach/gami/actions/workflows/on-push-branch-main-pytest.yml/badge.svg)](https://github.com/WesRoach/gami/actions/workflows/on-push-branch-main-pytest.yml)
[![Main-Formatting](https://github.com/WesRoach/gami/actions/workflows/on-push-branch-main-formatting.yml/badge.svg)](https://github.com/WesRoach/gami/actions/workflows/on-push-branch-main-formatting.yml)
[![License](https://img.shields.io/badge/License-MIT-yellow.svg)](https://github.com/WesRoach/gami/blob/main/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Produce synthetic health claims data.

[![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/WesRoach/gami)

## Introduction

This project is in an early planning stage and should not be relied upon.

## Default

```python
import gami

gami.generate()
```
